cobib-show(1) -- show an entry
==============================

## SYNOPSIS

`cobib show` _LABEL_

## DESCRIPTION

Shows the contents of an entry.
This simply dumps the output of the cobib-bibtex(7) parser of the entry called _LABEL_.

## EXAMPLES

```bash
$ cobib show Label1
```

## SEE ALSO

*cobib(1)*, *cobib-commands(7)*

[//]: # ( vim: set ft=markdown tw=0: )
